@@ -20,7 +20,7 @@
 mod channel;
 mod component;
 mod context;
-mod exception_frame;
+mod errors;
 mod execute;
 mod module;
 mod plugin;
@@ -29,11 +29,9 @@ mod tag;
 mod util;
 mod worker;
 
-use phper::{
-    ini::{Ini, Policy},
-    modules::Module,
-    php_get_module,
-};
+use phper::{ini::Policy, modules::Module, php_get_module};
+
+pub use errors::{Error, Result};
 
 /// Enable agent and report or not.
 const SKYWALKING_AGENT_ENABLE: &str = "skywalking_agent.enable";
@@ -56,6 +54,34 @@ const SKYWALKING_AGENT_LOG_LEVEL: &str = "skywalking_agent.log_level";
 /// Log file of skywalking agent.
 const SKYWALKING_AGENT_LOG_FILE: &str = "skywalking_agent.log_file";
 
+/// Skywalking agent runtime directory.
+const SKYWALKING_AGENT_RUNTIME_DIR: &str = "skywalking_agent.runtime_dir";
+
+/// Skywalking agent authentication token.
+const SKYWALKING_AGENT_AUTHENTICATION: &str = "skywalking_agent.authentication";
+
+/// Wether to enable tls for gPRC.
+const SKYWALKING_AGENT_ENABLE_TLS: &str = "skywalking_agent.enable_tls";
+
+/// The gRPC SSL trusted ca file.
+const SKYWALKING_AGENT_SSL_TRUSTED_CA_PATH: &str = "skywalking_agent.ssl_trusted_ca_path";
+
+/// The private key file. Enable mTLS when ssl_key_path and ssl_cert_chain_path
+/// exist.
+const SKYWALKING_AGENT_SSL_KEY_PATH: &str = "skywalking_agent.ssl_key_path";
+
+/// The certificate file. Enable mTLS when ssl_key_path and ssl_cert_chain_path
+/// exist.
+const SKYWALKING_AGENT_SSL_CERT_CHAIN_PATH: &str = "skywalking_agent.ssl_cert_chain_path";
+
+/// Agent heartbeat report period. Unit, second.
+const SKYWALKING_AGENT_HEARTBEAT_PERIOD: &str = "skywalking_agent.heartbeat_period";
+
+/// The agent sends the instance properties to the backend every
+/// heartbeat_period * properties_report_period_factor seconds.
+const SKYWALKING_AGENT_PROPERTIES_REPORT_PERIOD_FACTOR: &str =
+    "skywalking_agent.properties_report_period_factor";
+
 #[php_get_module]
 pub fn get_module() -> Module {
     let mut module = Module::new(
@@ -65,29 +91,61 @@ pub fn get_module() -> Module {
     );
 
     // Register skywalking ini.
-    Ini::add(SKYWALKING_AGENT_ENABLE, false, Policy::System);
-    Ini::add(SKYWALKING_AGENT_SKYWALKING_VERSION, 8i64, Policy::System);
-    Ini::add(
+    module.add_ini(SKYWALKING_AGENT_ENABLE, false, Policy::System);
+    module.add_ini(SKYWALKING_AGENT_SKYWALKING_VERSION, 8i64, Policy::System);
+    module.add_ini(
         SKYWALKING_AGENT_SERVER_ADDR,
-        "http://127.0.0.1:11800".to_string(),
+        "127.0.0.1:11800".to_string(),
         Policy::System,
     );
-    Ini::add(
+    module.add_ini(
         SKYWALKING_AGENT_SERVICE_NAME,
         "hello-skywalking".to_string(),
         Policy::System,
     );
-    Ini::add(SKYWALKING_AGENT_WORKER_THREADS, 0i64, Policy::System);
-    Ini::add(
+    module.add_ini(SKYWALKING_AGENT_WORKER_THREADS, 0i64, Policy::System);
+    module.add_ini(
         SKYWALKING_AGENT_LOG_LEVEL,
         "OFF".to_string(),
         Policy::System,
     );
-    Ini::add(
+    module.add_ini(
         SKYWALKING_AGENT_LOG_FILE,
         "/tmp/skywalking-agent.log".to_string(),
         Policy::System,
     );
+    module.add_ini(
+        SKYWALKING_AGENT_RUNTIME_DIR,
+        "/tmp/skywalking-agent".to_string(),
+        Policy::System,
+    );
+    module.add_ini(
+        SKYWALKING_AGENT_AUTHENTICATION,
+        "".to_string(),
+        Policy::System,
+    );
+    module.add_ini(SKYWALKING_AGENT_ENABLE_TLS, false, Policy::System);
+    module.add_ini(
+        SKYWALKING_AGENT_SSL_TRUSTED_CA_PATH,
+        "".to_string(),
+        Policy::System,
+    );
+    module.add_ini(
+        SKYWALKING_AGENT_SSL_KEY_PATH,
+        "".to_string(),
+        Policy::System,
+    );
+    module.add_ini(
+        SKYWALKING_AGENT_SSL_CERT_CHAIN_PATH,
+        "".to_string(),
+        Policy::System,
+    );
+    module.add_ini(SKYWALKING_AGENT_HEARTBEAT_PERIOD, 30i64, Policy::System);
+    module.add_ini(
+        SKYWALKING_AGENT_PROPERTIES_REPORT_PERIOD_FACTOR,
+        10i64,
+        Policy::System,
+    );
 
     // Hooks.
     module.on_module_init(module::init);
@@ -100,7 +158,6 @@ pub fn get_module() -> Module {
     module.add_function(
         "skywalking_hack_swoole_on_request_please_do_not_use",
         request::skywalking_hack_swoole_on_request,
-        vec![],
     );
 
     module
